==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/GeographicXYTriangulatingSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapSeriesHostDescriptionMetadata } from "./GeographicMapSeriesHostDescriptionMetadata";
/**
 * @hidden
 */
var GeographicXYTriangulatingSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicXYTriangulatingSeriesDescriptionMetadata, _super);
    function GeographicXYTriangulatingSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicXYTriangulatingSeriesDescriptionMetadata.b = function (a) {
        if (GeographicXYTriangulatingSeriesDescriptionMetadata.a == null) {
            GeographicXYTriangulatingSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicXYTriangulatingSeriesDescriptionMetadata.c(GeographicXYTriangulatingSeriesDescriptionMetadata.a);
        }
        if (a.g(GeographicXYTriangulatingSeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(GeographicXYTriangulatingSeriesDescriptionMetadata.a);
    };
    GeographicXYTriangulatingSeriesDescriptionMetadata.c = function (a) {
        GeographicMapSeriesHostDescriptionMetadata.c(a);
        a.item("LongitudeMemberPath", "String");
        a.item("LatitudeMemberPath", "String");
        a.item("TrianglesSourceRef", "(w:TrianglesSource,wf:TrianglesSource)DataRef::object");
        a.item("TriangleVertexMemberPath1", "String");
        a.item("TriangleVertexMemberPath2", "String");
        a.item("TriangleVertexMemberPath3", "String");
    };
    GeographicXYTriangulatingSeriesDescriptionMetadata.d = function (a) {
        GeographicXYTriangulatingSeriesDescriptionMetadata.b(a);
        a.t("GeographicXYTriangulatingSeries", GeographicXYTriangulatingSeriesDescriptionMetadata.a);
    };
    GeographicXYTriangulatingSeriesDescriptionMetadata.$t = markType(GeographicXYTriangulatingSeriesDescriptionMetadata, 'GeographicXYTriangulatingSeriesDescriptionMetadata');
    GeographicXYTriangulatingSeriesDescriptionMetadata.a = null;
    return GeographicXYTriangulatingSeriesDescriptionMetadata;
}(Base));
export { GeographicXYTriangulatingSeriesDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GeographicXYTriangulatingSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapSeriesHostDescriptionMetadata } from "./GeographicMapSeriesHostDescriptionMetadata";
/**
 * @hidden
 */
var GeographicXYTriangulatingSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GeographicXYTriangulatingSeriesDescriptionMetadata, _super);
    function GeographicXYTriangulatingSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicXYTriangulatingSeriesDescriptionMetadata.b = function (a) {
        if (GeographicXYTriangulatingSeriesDescriptionMetadata.a == null) {
            GeographicXYTriangulatingSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicXYTriangulatingSeriesDescriptionMetadata.c(GeographicXYTriangulatingSeriesDescriptionMetadata.a);
        }
        if (a.j(GeographicXYTriangulatingSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(GeographicXYTriangulatingSeriesDescriptionMetadata.a);
    };
    GeographicXYTriangulatingSeriesDescriptionMetadata.c = function (a) {
        GeographicMapSeriesHostDescriptionMetadata.c(a);
        a.item("LongitudeMemberPath", "String");
        a.item("LatitudeMemberPath", "String");
        a.item("TrianglesSourceRef", "(w:TrianglesSource,wf:TrianglesSource)DataRef::object");
        a.item("TriangleVertexMemberPath1", "String");
        a.item("TriangleVertexMemberPath2", "String");
        a.item("TriangleVertexMemberPath3", "String");
    };
    GeographicXYTriangulatingSeriesDescriptionMetadata.d = function (a) {
        GeographicXYTriangulatingSeriesDescriptionMetadata.b(a);
        a.z("GeographicXYTriangulatingSeries", GeographicXYTriangulatingSeriesDescriptionMetadata.a);
    };
    GeographicXYTriangulatingSeriesDescriptionMetadata.$t = markType(GeographicXYTriangulatingSeriesDescriptionMetadata, 'GeographicXYTriangulatingSeriesDescriptionMetadata');
    GeographicXYTriangulatingSeriesDescriptionMetadata.a = null;
    return GeographicXYTriangulatingSeriesDescriptionMetadata;
}(Base));
export { GeographicXYTriangulatingSeriesDescriptionMetadata };
